==> multipaper-api-1.19.3-R0.1-20230209.150747-1-sources.jar: org/bukkit/Instrument.java <==
package org.bukkit;

import com.google.common.collect.Maps;
import java.util.Map;
import org.jetbrains.annotations.Nullable;

public enum Instrument {

    /**
     * Piano (Harp) is the standard instrument for a note block.
     */
    PIANO(0x0),
    /**
     * Bass drum is normally played when a note block is on top of a
     * stone-like block.
     */
    BASS_DRUM(0x1),
    /**
     * Snare drum is normally played when a note block is on top of a sandy
     * block.
     */
    SNARE_DRUM(0x2),
    /**
     * Sticks (Hat) are normally played when a note block is on top of a glass
     * block.
     */
    STICKS(0x3),
    /**
     * Bass guitar is normally played when a note block is on top of a wooden
     * block.
     */
    BASS_GUITAR(0x4),
    /**
     * Flute is normally played when a note block is on top of a clay block.
     */
    FLUTE(0x5),
    /**
     * Bell is normally played when a note block is on top of a gold block.
     */
    BELL(0x6),
    /**
     * Guitar is normally played when a note block is on top of a woolen block.
     */
    GUITAR(0x7),
    /**
     * Chime is normally played when a note block is on top of a packed ice
     * block.
     */
    CHIME(0x8),
    /**
     * Xylophone is normally played when a note block is on top of a bone block.
     */
    XYLOPHONE(0x9),
    /**
     * Iron Xylophone is normally played when a note block is on top of a iron block.
     */
    IRON_XYLOPHONE(0xA),
    /**
     * Cow Bell is normally played when a note block is on top of a soul sand block.
     */
    COW_BELL(0xB),
    /**
     * Didgeridoo is normally played when a note block is on top of a pumpkin block.
     */
    DIDGERIDOO(0xC),
    /**
     * Bit is normally played when a note block is on top of a emerald block.
     */
    BIT(0xD),
    /**
     * Banjo is normally played when a note block is on top of a hay block.
     */
    BANJO(0xE),
    /**
     * Pling is normally played when a note block is on top of a glowstone block.
     */
    PLING(0xF),
    /**
     * Zombie is normally played when a Zombie Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper
    ZOMBIE(0x10), // Paper
    /**
     * Skeleton is normally played when a Skeleton Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper
    SKELETON(0x11), // Paper
    /**
     * Creeper is normally played when a Creeper Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper
    CREEPER(0x12), // Paper
    /**
     * Dragon is normally played when a Dragon Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper
    DRAGON(0x13), // Paper
    /**
     * Wither Skeleton is normally played when a Wither Skeleton Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper
    WITHER_SKELETON(0x14), // Paper
    /**
     * Piglin is normally played when a Piglin Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper
    PIGLIN(0x15), // Paper
    /**
     * Custom Sound is normally played when a Player Head with the required data is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper
    CUSTOM_HEAD(0x16); // Paper

    private final byte type;
    private static final Map<Byte, Instrument> BY_DATA = Maps.newHashMap();

    // Paper - remove ctor (the server still uses the byte magic value)

    private Instrument(final int type) {
        this.type = (byte) type;
    }

    /**
     * @return The type ID of this instrument.
     */
    @org.jetbrains.annotations.ApiStatus.Internal // Paper
    public byte getType() {
        return this.type;
    }

    /**
     * Get an instrument by its type ID.
     *
     * @param type The type ID
     * @return The instrument
     */
    @org.jetbrains.annotations.ApiStatus.Internal // Paper
    @Nullable
    public static Instrument getByType(final byte type) {
        return BY_DATA.get(type);
    }

    static {
        for (Instrument instrument : Instrument.values()) {
            BY_DATA.put(instrument.getType(), instrument);
        }
    }
}

==> multipaper-api-1.19.4-R0.1-20230327.070438-1-sources.jar: org/bukkit/Instrument.java <==
package org.bukkit;

import com.google.common.collect.Maps;
import java.util.Map;
import org.jetbrains.annotations.Nullable;

public enum Instrument {

    /**
     * Piano (Harp) is the standard instrument for a note block.
     */
    PIANO(0x0),
    /**
     * Bass drum is normally played when a note block is on top of a
     * stone-like block.
     */
    BASS_DRUM(0x1),
    /**
     * Snare drum is normally played when a note block is on top of a sandy
     * block.
     */
    SNARE_DRUM(0x2),
    /**
     * Sticks (Hat) are normally played when a note block is on top of a glass
     * block.
     */
    STICKS(0x3),
    /**
     * Bass guitar is normally played when a note block is on top of a wooden
     * block.
     */
    BASS_GUITAR(0x4),
    /**
     * Flute is normally played when a note block is on top of a clay block.
     */
    FLUTE(0x5),
    /**
     * Bell is normally played when a note block is on top of a gold block.
     */
    BELL(0x6),
    /**
     * Guitar is normally played when a note block is on top of a woolen block.
     */
    GUITAR(0x7),
    /**
     * Chime is normally played when a note block is on top of a packed ice
     * block.
     */
    CHIME(0x8),
    /**
     * Xylophone is normally played when a note block is on top of a bone block.
     */
    XYLOPHONE(0x9),
    /**
     * Iron Xylophone is normally played when a note block is on top of a iron block.
     */
    IRON_XYLOPHONE(0xA),
    /**
     * Cow Bell is normally played when a note block is on top of a soul sand block.
     */
    COW_BELL(0xB),
    /**
     * Didgeridoo is normally played when a note block is on top of a pumpkin block.
     */
    DIDGERIDOO(0xC),
    /**
     * Bit is normally played when a note block is on top of a emerald block.
     */
    BIT(0xD),
    /**
     * Banjo is normally played when a note block is on top of a hay block.
     */
    BANJO(0xE),
    /**
     * Pling is normally played when a note block is on top of a glowstone block.
     */
    PLING(0xF),
    /**
     * Zombie is normally played when a Zombie Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper - 1.20
    ZOMBIE(0x10), // Paper
    /**
     * Skeleton is normally played when a Skeleton Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper - 1.20
    SKELETON(0x11), // Paper
    /**
     * Creeper is normally played when a Creeper Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper - 1.20
    CREEPER(0x12), // Paper
    /**
     * Dragon is normally played when a Dragon Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper - 1.20
    DRAGON(0x13), // Paper
    /**
     * Wither Skeleton is normally played when a Wither Skeleton Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper - 1.20
    WITHER_SKELETON(0x14), // Paper
    /**
     * Piglin is normally played when a Piglin Head is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper - 1.20
    PIGLIN(0x15), // Paper
    /**
     * Custom Sound is normally played when a Player Head with the required data is on top of the note block.
     */
    @org.jetbrains.annotations.ApiStatus.Experimental // Paper - 1.20
    CUSTOM_HEAD(0x16); // Paper

    private final byte type;
    private static final Map<Byte, Instrument> BY_DATA = Maps.newHashMap();

    // Paper - remove ctor (the server still uses the byte magic value)

    private Instrument(final int type) {
        this.type = (byte) type;
    }

    /**
     * @return The type ID of this instrument.
     */
    @org.jetbrains.annotations.ApiStatus.Internal // Paper
    public byte getType() {
        return this.type;
    }

    /**
     * Get an instrument by its type ID.
     *
     * @param type The type ID
     * @return The instrument
     */
    @org.jetbrains.annotations.ApiStatus.Internal // Paper
    @Nullable
    public static Instrument getByType(final byte type) {
        return BY_DATA.get(type);
    }

    static {
        for (Instrument instrument : Instrument.values()) {
            BY_DATA.put(instrument.getType(), instrument);
        }
    }
}
